from baseapp_auth.models import AbstractUser
from baseapp_core.graphql.models import RelayModel
from baseapp_profiles.models import ProfilableModel
from baseapp_profiles.signals import update_user_profile
from django.db.models.signals import post_save
from django.utils import timezone
from model_utils import FieldTracker

from baseapp_ratings.models import RatableModel


class User(AbstractUser, RelayModel, RatableModel, ProfilableModel):
    # FieldTracker doesn't work with abstract model classes
    tracker = FieldTracker(fields=["is_superuser", "password"])

    def save(self, *args, **kwargs):
        with self.tracker:
            if self.tracker.has_changed("password"):
                self.password_changed_date = timezone.now()
            super().save(*args, **kwargs)


post_save.connect(update_user_profile, sender=User)



import graphene
from baseapp_auth.graphql.queries import UsersQueries
from baseapp_core.graphql import DeleteNode
from graphene import relay

from baseapp_ratings.graphql.mutations import RatingsMutations
from baseapp_ratings.graphql.queries import RatingsQueries


class Query(graphene.ObjectType, RatingsQueries, UsersQueries):
    node = relay.node.NodeField(relay.Node)


class Mutation(
    graphene.ObjectType,
    RatingsMutations,
):
    delete_node = DeleteNode.Field()


schema = graphene.Schema(query=Query, mutation=Mutation)



# Generated by Django 5.0.6 on 2024-05-20 15:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("testapp", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="user",
            name="is_ratings_enabled",
            field=models.BooleanField(default=True),
        ),
        migrations.AddField(
            model_name="user",
            name="ratings_average",
            field=models.FloatField(default=0, editable=False),
        ),
        migrations.AddField(
            model_name="user",
            name="ratings_count",
            field=models.IntegerField(default=0, editable=False),
        ),
        migrations.AddField(
            model_name="user",
            name="ratings_sum",
            field=models.IntegerField(default=0, editable=False),
        ),
    ]
